Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var DefaultArguments = Arguments{ APIURL: "https://api.scaleway.com", Zone: scw.ZoneFrPar1.String(), RefreshInterval: 60 * time.Second, Port: 80, FollowRedirects: true, EnableHTTP2: true, }
Functions ¶
Types ¶
type Arguments ¶
type Arguments struct {
Project string `river:"project_id,attr"`
Role Role `river:"role,attr"`
APIURL string `river:"api_url,attr,optional"`
Zone string `river:"zone,attr,optional"`
AccessKey string `river:"access_key,attr"`
SecretKey rivertypes.Secret `river:"secret_key,attr,optional"`
SecretKeyFile string `river:"secret_key_file,attr,optional"`
NameFilter string `river:"name_filter,attr,optional"`
TagsFilter []string `river:"tags_filter,attr,optional"`
RefreshInterval time.Duration `river:"refresh_interval,attr,optional"`
Port int `river:"port,attr,optional"`
ProxyConfig *config.ProxyConfig `river:",squash"`
TLSConfig config.TLSConfig `river:"tls_config,block,optional"`
FollowRedirects bool `river:"follow_redirects,attr,optional"`
EnableHTTP2 bool `river:"enable_http2,attr,optional"`
}
func (*Arguments) Convert ¶
func (args *Arguments) Convert() *prom_discovery.SDConfig
func (*Arguments) SetToDefault ¶
func (args *Arguments) SetToDefault()
SetToDefault implements river.Defaulter.
type Role ¶
type Role string
Role is the role of the target within the Scaleway Ecosystem.
func (Role) MarshalText ¶
MarshalText implements encoding.TextMarshaler, returning the raw bytes of the Role.
func (*Role) UnmarshalText ¶
UnmarshalText implements encoding.TextUnmarshaler. UnmarshalText returns an error if the text is not recognized as a valid Role.
Click to show internal directories.
Click to hide internal directories.